pub struct TokenRecord { /* private fields */ }Expand description
Binary representation of a token.
The text itself is stored separately inside the token string table.
offset is relative to the beginning of that section.
Binary layout:
- token id: 4 bytes
- reserved: 4 bytes
- string offset: 8 bytes
- string length: 4 bytes
- reserved: 4 bytes
Implementations
Sourceimpl TokenRecord
impl TokenRecord
pub const SIZE: usize = TOKEN_RECORD_SIZE
pub const fn new(id: u32, offset: u64, length: u32) -> Self
pub const fn id(self) -> u32
pub const fn offset(self) -> u64
pub const fn length(self) -> u32
pub const fn end(self) -> u64
pub fn encode(self) -> [u8; 24]
pub fn decode(bytes: &[u8]) -> Result<Self, FormatError>